ORDER_DELETED = "OrderDeleted"
ORDER_WRITTEN_SALE = "OrderWrittenSale"
FULFILMENT_SCHEDULED_DELIVERY = "FulfillmentScheduledDelivery"
FULFILMENT_FULLY_RESERVED = "FulfillmentFullyReserved"
FULFILMENT_COPLETED = "FulfillmentCompleted"

EVENTS = [
    ORDER_DELETED,
    ORDER_WRITTEN_SALE,
    FULFILMENT_SCHEDULED_DELIVERY,
    FULFILMENT_FULLY_RESERVED,
    FULFILMENT_COPLETED,    
    ]
